/*****************************************************************************
** STAIR VISION LIBRARY
** Copyright (c) 2007-2009, Stephen Gould
** All rights reserved.
**
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the Stanford University nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ``AS IS'' AND ANY
** EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
** DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
** (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
** LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
** ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
******************************************************************************
** FILENAME:    scaleDetections.cpp
** AUTHOR(S):   Olga Russakovsky <olga@cs.stanford.edu>
**
** DESCRIPTION:
**  Scales the detection
**
*****************************************************************************/

#include <cstdlib>
#include <cassert>
#include <iostream>
#include <fstream>
#include <iomanip>
#include <vector>
#include <string.h>

#include "cv.h"
#include "cxcore.h"
#include "highgui.h"

#include "svlBase.h"
#include "svlML.h"
#include "svlVision.h"

using namespace std;

// main -----------------------------------------------------------------------

void usage()
{
    cerr << SVL_USAGE_HEADER << endl;
    cerr << "USAGE: ./scaleDetections <detections filename> <outputFilename> " << endl;
    cerr << "OPTIONS:" << endl
         << "  -s <scale>         :: multiplies all detections by that scale" << endl
	 << endl;
}

#define NUM_REQUIRED_PARAMETERS 2

int main(int argc, char *argv[])
{		
       
  float scale = 1.0;
   
  char **args = argv + 1;
  while (--argc) {
    if (!strcmp(*args, "-s")) {
      scale = atof(*argv);
    } else if (**args == '-') {
      SVL_LOG(SVL_LOG_FATAL, "unrecognized option " << *args);
    } else {
      break;
    }
    args++;
  }

  if (argc < NUM_REQUIRED_PARAMETERS) 
    {
      usage();
      return -1;
    }
  
  const char *detectionsFilename = args[0];
  const char *outputFilename = args[1];
  
  svlObject2dSequence detections;
  readObject2dSequence(detectionsFilename, detections);
  scaleObject2dSequence(detections, scale, scale);
  writeObject2dSequence(outputFilename, detections);
  return 0;
}
